@@ -1,5 +1,5 @@
 """AMQP Messaging Framework for Python"""
-VERSION = (0, 1, 0)
+VERSION = (0, 2, 0)
 __version__ = ".".join(map(str, VERSION))
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
@@ -9,5 +9,5 @@ __docformat__ = "restructuredtext"
 import os
 if not os.environ.get("KOMBU_NO_EVAL", False):
     from kombu.connection import BrokerConnection
-    from kombu.entity import Exchange, Binding
+    from kombu.entity import Exchange, Queue
     from kombu.messaging import Consumer, Producer
