@@ -2,13 +2,13 @@ import unittest2 as unittest
 
 from kombu.connection import BrokerConnection
 
-from kombu.tests.mocks import Backend
+from kombu.tests.mocks import Transport
 
 
 class test_Connection(unittest.TestCase):
 
     def test_establish_connection(self):
-        conn = BrokerConnection(port=5672, backend_cls=Backend)
+        conn = BrokerConnection(port=5672, transport=Transport)
         conn.connect()
         self.assertTrue(conn.connection.connected)
         self.assertEqual(conn.host, "localhost:5672")
@@ -18,10 +18,10 @@ class test_Connection(unittest.TestCase):
         _connection = conn.connection
         conn.close()
         self.assertFalse(_connection.connected)
-        self.assertIsInstance(conn.backend, Backend)
+        self.assertIsInstance(conn.transport, Transport)
 
     def test__enter____exit__(self):
-        conn = BrokerConnection(backend_cls=Backend)
+        conn = BrokerConnection(transport=Transport)
         context = conn.__enter__()
         self.assertIs(context, conn)
         conn.connect()
